@@ -1,10 +1,10 @@
 #       sha1sum python plugin
-#       Copyright (C) 2007-2010 Piotr Eljasiak
+#       Copyright (C) 2007-2011 Piotr Eljasiak
 #
 #    Part of
 #       GNOME Commander - A GNOME based file manager
 #       Copyright (C) 2001-2006 Marcus Bjurman
-#       Copyright (C) 2007-2010 Piotr Eljasiak
+#       Copyright (C) 2007-2011 Piotr Eljasiak
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
+import warnings
+
+warnings.simplefilter("ignore", DeprecationWarning)
+
 try:
     import gnomevfs
 except ImportError:
