@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +26,7 @@
 
 void gcmd_tags_libgsf_init();
 void gcmd_tags_libgsf_shutdown();
-void gcmd_tags_libgsf_load_metadata(GnomeCmdFile *finfo);
+
+void gcmd_tags_libgsf_load_metadata(GnomeCmdFile *f);
 
 #endif // __GNOME_CMD_TAGS_DOC_H__
